pub struct DiscoverResult {
pub contents: Vec<Content>,
pub errors: Vec<(PathBuf, Error)>,
}Expand description
Result of discovering content posts in a directory.
Contains both successfully loaded posts and any errors encountered. The caller can decide how to handle errors (e.g., log them, display warnings).
Fields
contents: Vec<Content>Successfully loaded content posts, sorted by created date (newest first)
errors: Vec<(PathBuf, Error)>Errors encountered while loading posts: (path, error)