pub struct PostPlatformConfig {
pub published: Option<bool>,
pub internal_link_target: Option<String>,
pub extra: HashMap<String, Value>,
}Expand description
Per-post platform configuration (overrides global)
Fields
published: Option<bool>Per-content platform-specific published setting (layer 1 per [[RFC-0005:C-RESOLUTION-ORDER]])
internal_link_target: Option<String>Per-content platform-specific internal link target (layer 1 in resolution chain)
extra: HashMap<String, Value>Implementations
Sourceimpl PostPlatformConfig
impl PostPlatformConfig
Sourcepub fn get_str(&self, key: &str) -> Option<String>
pub fn get_str(&self, key: &str) -> Option<String>
Get a string value from config, expanding environment variables.
Supports shell-like variable substitution via the subst crate:
$VARor${VAR}— substitute from environment${VAR:default}— use default if VAR is unset
Sourcepub fn get_str_raw(&self, key: &str) -> Option<&str>
pub fn get_str_raw(&self, key: &str) -> Option<&str>
Get a raw string value without environment variable expansion.